# eric7.WebBrowser.StatusBar.JavaScriptSettingsDialog

Module implementing the JavaScript settings dialog.

### Global Attributes

None

### Classes

JavaScriptSettingsDialog | Class implementing the JavaScript settings dialog.

### Functions

None

## JavaScriptSettingsDialog

Class implementing the JavaScript settings dialog.

Note: it contains the JavaScript part of the web browser configuration dialog.

### Derived from

QDialog, Ui_JavaScriptSettingsDialog

### Class Attributes

None

### Class Methods

None

### Methods

JavaScriptSettingsDialog | Constructor
accept | Public slot to accept the dialog.

### Static Methods

None

#### JavaScriptSettingsDialog (Constructor)

JavaScriptSettingsDialog(parent=None)

Constructor

parent (QWidget)
  reference to the parent widget

#### JavaScriptSettingsDialog.accept

accept()

Public slot to accept the dialog.

Up